#!/bin/sh

# See where we are
# set

export MACOSX_DEPLOYMENT_TARGET=10.2

cd $BUILD_DIR
make